Package: urlchecker
Title: Run CRAN URL Checks from Older R Versions
Version: 1.0.1
Authors@R: c(
    person("R Core team", role = "aut",
           comment = "The code in urltools.R adapted from the tools package"),
    person("Jim", "Hester", role = "aut",
           comment = c(ORCID = "0000-0002-2739-7082")),
    person("Gábor", "Csárdi", , "csardi.gabor@gmail.com", role = c("aut", "cre")),
    person("RStudio", role = c("cph", "fnd"))
  )
Description: Provide the URL checking tools available in R 4.1+ as a
    package for earlier versions of R. Also uses concurrent requests so
    can be much faster than the serial versions.
License: GPL-3
URL: https://github.com/r-lib/urlchecker
BugReports: https://github.com/r-lib/urlchecker/issues
Depends: R (>= 3.3)
Imports: cli, curl, tools, xml2
Suggests: covr
Encoding: UTF-8
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2021-11-30 00:26:56 UTC; jhester
Author: R Core team [aut] (The code in urltools.R adapted from the tools
    package),
  Jim Hester [aut] (<https://orcid.org/0000-0002-2739-7082>),
  Gábor Csárdi [aut, cre],
  RStudio [cph, fnd]
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2021-11-30 13:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 09:36:28 UTC; unix
