Package: urlchecker
Title: Run CRAN URL Checks from Older R Versions
Version: 2.0.0
Authors@R: c(
    person("R Core team", role = "aut",
           comment = "The code in urltools.R adapted from the tools package"),
    person("Jim", "Hester", role = "aut",
           comment = c(ORCID = "0000-0002-2739-7082")),
    person("Gábor", "Csárdi", , "csardi.gabor@gmail.com", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Provide the URL checking tools available in R 4.1+ as a
    package for earlier versions of R. Also uses concurrent requests so
    can be much faster than the serial versions.
License: GPL-3
URL: https://github.com/r-lib/urlchecker, https://urlchecker.r-lib.org/
BugReports: https://github.com/r-lib/urlchecker/issues
Depends: R (>= 4.1)
Imports: cli, curl, gitcreds, rlang (>= 1.1.0), tools, utils, xml2
Suggests: covr, testthat (>= 3.0.0), webfakes, withr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: url_check, qmd, url_update, print
Config/usethis/last-upkeep: 2025-05-07
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-08 15:53:55 UTC; gaborcsardi
Author: R Core team [aut] (The code in urltools.R adapted from the tools
    package),
  Jim Hester [aut] (ORCID: <https://orcid.org/0000-0002-2739-7082>),
  Gábor Csárdi [aut, cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-08 16:30:08 UTC
