% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/url_update.R
\name{url_update}
\alias{url_update}
\title{Update URLs in a package}
\usage{
url_update(path = ".", results = url_check(path))
}
\arguments{
\item{path}{Path to the package}

\item{results}{results from \link{url_check}.}
}
\value{
The results from \code{url_check(path)}, invisibly.
}
\description{
First uses \link{url_check} to check and then updates any URLs which are permanent (301)
redirects.
}
\examples{
\dontrun{
url_update("my_pkg")
}
}
