% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/urlchecker-package.R
\docType{package}
\name{urlchecker-package}
\alias{urlchecker}
\alias{urlchecker-package}
\title{urlchecker: Run CRAN URL Checks from Older R Versions}
\description{
Provide the URL checking tools available in R 4.1+ as a package for earlier versions of R. Also uses concurrent requests so can be much faster than the serial versions.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/r-lib/urlchecker}
  \item \url{https://urlchecker.r-lib.org/}
  \item Report bugs at \url{https://github.com/r-lib/urlchecker/issues}
}

}
\author{
\strong{Maintainer}: Gábor Csárdi \email{csardi.gabor@gmail.com}

Authors:
\itemize{
  \item Gábor Csárdi \email{csardi.gabor@gmail.com}
  \item R Core team (The code in urltools.R adapted from the tools package)
  \item Jim Hester (\href{https://orcid.org/0000-0002-2739-7082}{ORCID})
}

Other contributors:
\itemize{
  \item Posit Software, PBC (\href{https://ror.org/03wc8by49}{ROR}) [copyright holder, funder]
}

}
\keyword{internal}
